# nornir-salt

Collection of Nornir plugins for [SALTSTACK Nornir Proxy Minion modules](https://github.com/dmulyalin/salt-nornir).

All plugins and functions can be used with Nornir directly unless stated otherwise.

Refer to [documentation](https://nornir-salt.readthedocs.io/en/latest/) for additional information.

# Contributing

Issues, bug reports and feature requests are welcomed.